PALM-meteo: palmmeteo.config.ConfigObj Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Protected Member Functions | Protected Attributes | List of all members
palmmeteo.config.ConfigObj Class Reference
Inheritance diagram for palmmeteo.config.ConfigObj:
[legend]
Collaboration diagram for palmmeteo.config.ConfigObj:
[legend]

## Public Member Functions
| __init__ (self, parent=None, name=None)
| __getattr__ (self, name)
| __getitem__ (self, key)
| __contains__ (self, key)
| __iter__ (self)

## Protected Member Functions
| _ingest_dict (self, d, overwrite=True, extend=False, check_exist=False)
| _ingest_module_config (self, modname)
| _get_path (self)

## Protected Attributes
| _parent
| _name
| _settings

## Detailed Description

    A recursive object within a hierarchical configuration, representing
    a (sub)section as a dictionary from the YAML configuration file. Child
    nodes may be accessed both by the dot notation (section.setting) and the
    item notation (section['setting']).

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.config.ConfigObj.__init__ | ( |  | self,
|  |  | parent = `None`,
|  |  | name = `None`
| ) |  |

## Member Function Documentation

## ◆ __contains__()

palmmeteo.config.ConfigObj.__contains__ | ( |  | self,
|  |  | key
| ) |  |

## ◆ __getattr__()

palmmeteo.config.ConfigObj.__getattr__ | ( |  | self,
|  |  | name
| ) |  |

## ◆ __getitem__()

palmmeteo.config.ConfigObj.__getitem__ | ( |  | self,
|  |  | key
| ) |  |

## ◆ __iter__()

palmmeteo.config.ConfigObj.__iter__ | ( |  | self | ) |

## ◆ _get_path()

palmmeteo.config.ConfigObj._get_path | ( |  | self | ) |
| protected

## ◆ _ingest_dict()

palmmeteo.config.ConfigObj._ingest_dict | ( |  | self,
|  |  | d,
|  |  | overwrite = `True`,
|  |  | extend = `False`,
|  |  | check_exist = `False`
| ) |  |
| protected

## ◆ _ingest_module_config()

palmmeteo.config.ConfigObj._ingest_module_config | ( |  | self,
|  |  | modname
| ) |  |
| protected

    Locates the initial configuration file config_init.yaml within module
    code and ingests it.

## Member Data Documentation

## ◆ _name

palmmeteo.config.ConfigObj._name
| protected

## ◆ _parent

palmmeteo.config.ConfigObj._parent
| protected

## ◆ _settings

palmmeteo.config.ConfigObj._settings
| protected

The documentation for this class was generated from the following file:

- palmmeteo/config.py